@@ -1,7 +1,16 @@
+__author__ = "Pawel Kowalik"
+__copyright__ = "Copyright 2018, 1&1 IONOS SE"
+__credits__ = []
+__license__ = "MIT"
+__maintainer__ = "Pawel Kowalik"
+__email__ = "pawel-kow@users.noreply.github.com"
+__status__ = "Beta"
+
 def stringify_keys(d):
     """Convert a dict's keys to strings if they are not."""
     if hasattr(d, 'keys'):
-        for key in d.keys():
+        to_iterate = list(d.keys())
+        for key in to_iterate:
 
             # check inner dict
             if isinstance(d[key], dict):
@@ -11,6 +20,7 @@ def stringify_keys(d):
 
             # convert nonstring to string if needed
             if not isinstance(key, str):
+                # noinspection PyBroadException
                 try:
                     d[str(key)] = value
                 except Exception:
@@ -27,4 +37,4 @@ def stringify_keys(d):
             if isinstance(getattr(d, k), dict):
                 setattr(d, k, stringify_keys(getattr(d, k)))
 
-    return d
\ No newline at end of file
+    return d
